SFS-package: Sampling the set of feasible solutions from a non-negative...

Description Author(s) References Examples

Description

The package include both a function NMFPois, that finds an initial non-negative matrix factorization(NMF) and a function sampleSFS that can recover the whole set of feasible solutions given an initial solution. Other than that there is a function used to convert the results into SVD representtion samplesToSVD.

Author(s)

Ragnhild Laursen

Maintainer: Ragnhild Laursen <ragnhild@math.au.dk>

References

Ragnhild Laursen and Asger Hobolth. A sampling algorithm to compute the set of feasible solutions for non-negative matrix factorization for a general number of components.

Examples

1
2
3
x = matrix(rpois(24,c(10:34)),4,6)
res = NMFPois(x,3)           # Finding an intial NMF solution
sfs = sampleSFS(res$P,res$E) # Finding the SFS

ragnhildlaursen/SFS documentation built on Nov. 15, 2021, 8:28 p.m.