Description Author(s) References Examples
The package include both a function NMFPois, that finds an initial non-negative matrix factorization(NMF) and a function sampleSFS that can recover the whole set of feasible solutions given an initial solution. Other than that there is a function used to convert the results into SVD representtion samplesToSVD.
Ragnhild Laursen
Maintainer: Ragnhild Laursen <ragnhild@math.au.dk>
Ragnhild Laursen and Asger Hobolth. A sampling algorithm to compute the set of feasible solutions for non-negative matrix factorization for a general number of components.
1 2 3 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.